==> react-uikit-components-0.1.5.tgz: package/README.md <==
# React UIkit Components Documentation

<p>
A collection of react components using <a href=http://getuikit.com/>UIkit CSS framework</a>.
<p/>

This module does not contain any components as they all have their own modules.

<p>
Examples and documentation can be found at <a href='http://otissv.github.io/react-uikit-components/'>react-uikit-components</a>
</a>
</p>

<ul>
  <li><a href='https://github.com/otissv/react-uikit-alert'>Alert</a></li>
  <li><a href='https://github.com/otissv/react-uikit-article'>Article</a></li>
  <li><a href='https://github.com/otissv/react-uikit-badge'>Badge</a></li>
  <li><a href='https://github.com/otissv/react-uikit-base'>Base</a></li>
  <li><a href='https://github.com/otissv/react-uikit-block'>Block</a></li>
  <li><a href='https://github.com/otissv/react-uikit-button'>Button</a></li>
  <li><a href='https://github.com/otissv/react-uikit-button-group'>Button Group</a></li>
  <li><a href='https://github.com/otissv/react-uikit-codeblock'>Codeblock</a></li>
  <li><a href='https://github.com/otissv/react-uikit-comment'>Comment</a></li>
  <li><a href='https://github.com/otissv/react-uikit-comment-list'>Comment List</a></li>
  <li><a href='https://github.com/otissv/react-uikit-dropdown'>Dropdown</a></li>
  <li><a href='https://github.com/otissv/react-uikit-flex'>Flex</a></li>
  <li><a href='https://github.com/otissv/react-uikit-grid'>Grid</a></li>
  <li><a href='https://github.com/otissv/react-uikit-img'>Img</a></li>
  <li><a href='https://github.com/otissv/react-uikit-img-gallery'>Img Gallery</a></li>
  <li><a href='https://github.com/otissv/react-uikit-list'>List</a></li>
  <li><a href='https://github.com/otissv/react-uikit-modal'>react-uikit-modal</a></li>
  <li><a href='https://github.com/otissv/react-uikit-note'>Note</a></li>
  <li><a href='https://github.com/otissv/react-uikit-overlay'>Overlay</a> </li>
  <li><a href='https://github.com/otissv/react-uikit-panel'>Panel</a></li>
  <li><a href='https://github.com/otissv/react-uikit-table'>Table</a></li>
  <li><a href='https://github.com/otissv/react-uikit-text'>Text</a></li>
  <li><a href='https://github.com/otissv/react-uikit-thumbnail'>Thumbnail</a></li>
  <li><a href='https://github.com/otissv/react-uikit-trigger'>Trigger</a></li>
</ul>

<section>
  <h2>License</h2>
    <p>MIT</p>
</section>

==> react-uikit-components-1.0.0.tgz: package/README.md <==
# React UIkit Components Documentation

<p>
A collection of react components using <a href=http://getuikit.com/>UIkit CSS framework</a>.
</p>

<p>
This module does not contain any components as they all have their own modules.
</p>



<p>
Examples and documentation can be found at <a href='http://otissv.github.io/react-uikit-components/'>react-uikit-components</a>
</a>
</p>

<p>
The master branch for each component has been updated to React 15. To use with React 0.14 checkout 0.14 branch.

</p>

<ul>
  <li><a href='https://github.com/otissv/react-uikit-alert'>Alert</a></li>
  <li><a href='https://github.com/otissv/react-uikit-article'>Article</a></li>
  <li><a href='https://github.com/otissv/react-uikit-badge'>Badge</a></li>
  <li><a href='https://github.com/otissv/react-uikit-base'>Base</a></li>
  <li><a href='https://github.com/otissv/react-uikit-block'>Block</a></li>
  <li><a href='https://github.com/otissv/react-uikit-button'>Button</a></li>
  <li><a href='https://github.com/otissv/react-uikit-button-group'>Button Group</a></li>
  <li><a href='https://github.com/otissv/react-uikit-codeblock'>Codeblock</a></li>
  <li><a href='https://github.com/otissv/react-uikit-comment'>Comment</a></li>
  <li><a href='https://github.com/otissv/react-uikit-comment-list'>Comment List</a></li>
  <li><a href='https://github.com/otissv/react-uikit-dropdown'>Dropdown</a></li>
  <li><a href='https://github.com/otissv/react-uikit-flex'>Flex</a></li>
  <li><a href='https://github.com/otissv/react-uikit-grid'>Grid</a></li>
  <li><a href='https://github.com/otissv/react-uikit-img'>Img</a></li>
  <li><a href='https://github.com/otissv/react-uikit-img-gallery'>Img Gallery</a></li>
  <li><a href='https://github.com/otissv/react-uikit-list'>List</a></li>
  <li><a href='https://github.com/otissv/react-uikit-modal'>Modal</a></li>
  <li><a href='https://github.com/otissv/react-uikit-note'>Note</a></li>
  <li><a href='https://github.com/otissv/react-uikit-overlay'>Overlay</a> </li>
  <li><a href='https://github.com/otissv/react-uikit-panel'>Panel</a></li>
  <li><a href='https://github.com/otissv/react-uikit-table'>Table</a></li>
  <li><a href='https://github.com/otissv/react-uikit-text'>Text</a></li>
  <li><a href='https://github.com/otissv/react-uikit-thumbnail'>Thumbnail</a></li>
  <li><a href='https://github.com/otissv/react-uikit-trigger'>Trigger</a></li>
</ul>

<section>
  <h2>License</h2>
    <p>MIT</p>
</section>
